chemfeat.features.calculators package
=====================================

Submodules
----------

chemfeat.features.calculators.ecfp module
-----------------------------------------

.. automodule:: chemfeat.features.calculators.ecfp
   :members:
   :undoc-members:
   :show-inheritance:

chemfeat.features.calculators.padel module
------------------------------------------

.. automodule:: chemfeat.features.calculators.padel
   :members:
   :undoc-members:
   :show-inheritance:

chemfeat.features.calculators.qed module
----------------------------------------

.. automodule:: chemfeat.features.calculators.qed
   :members:
   :undoc-members:
   :show-inheritance:

chemfeat.features.calculators.rdkdesc module
--------------------------------------------

.. automodule:: chemfeat.features.calculators.rdkdesc
   :members:
   :undoc-members:
   :show-inheritance:

chemfeat.features.calculators.rdkfp module
------------------------------------------

.. automodule:: chemfeat.features.calculators.rdkfp
   :members:
   :undoc-members:
   :show-inheritance:

chemfeat.features.calculators.secfp module
------------------------------------------

.. automodule:: chemfeat.features.calculators.secfp
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: chemfeat.features.calculators
   :members:
   :undoc-members:
   :show-inheritance:
